==> better_with_time-2.0-sources.jar: com/bwt/blocks/PedestalBlock.java <==
package com.bwt.blocks;

import net.minecraft.class_1750;
import net.minecraft.class_1922;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_2350;
import net.minecraft.class_259;
import net.minecraft.class_265;
import net.minecraft.class_2680;
import net.minecraft.class_2689;
import net.minecraft.class_2741;
import net.minecraft.class_2753;
import net.minecraft.class_3726;
import org.jetbrains.annotations.Nullable;

public class PedestalBlock extends DecorativeBlock {
    public static final class_2753 VERTICAL_DIRECTION = class_2741.field_28062;

    class_265 UP_SHAPE = class_259.method_17786(
            class_2248.method_9541(0, 0, 0, 16, 14, 16),
            class_2248.method_9541(1, 14, 1, 15, 15, 15),
            class_2248.method_9541(2, 15, 2, 14, 16, 14)
    );
    class_265 DOWN_SHAPE = class_259.method_17786(
            class_2248.method_9541(0, 2, 0, 16, 16, 16),
            class_2248.method_9541(1, 1, 1, 15, 2, 15),
            class_2248.method_9541(2, 0, 2, 14, 1, 14)
    );

    public PedestalBlock(class_2251 settings, class_2248 fullBlock) {
        super(settings, fullBlock);
        method_9590(method_9564().method_11657(VERTICAL_DIRECTION, class_2350.field_11036));
    }

    public static PedestalBlock ofBlock(class_2248 fullBlock) {
        return new PedestalBlock(class_2251.method_9630(fullBlock), fullBlock);
    }

    @Override
    protected void method_9515(class_2689.class_2690<class_2248, class_2680> builder) {
        super.method_9515(builder);
        builder.method_11667(VERTICAL_DIRECTION);
    }

    @Nullable
    @Override
    public class_2680 method_9605(class_1750 ctx) {
        return method_9564().method_11657(VERTICAL_DIRECTION, ctx.method_32760().method_10153());
    }

    @Override
    public class_265 method_9530(class_2680 state, class_1922 view, class_2338 pos, class_3726 context) {
        return state.method_11654(VERTICAL_DIRECTION) == class_2350.field_11036 ? UP_SHAPE : DOWN_SHAPE;
    }
}

==> better_with_time-2.0.2-sources.jar: com/bwt/blocks/PedestalBlock.java <==
package com.bwt.blocks;

import net.minecraft.class_1750;
import net.minecraft.class_1922;
import net.minecraft.class_2248;
import net.minecraft.class_2338;
import net.minecraft.class_2350;
import net.minecraft.class_259;
import net.minecraft.class_265;
import net.minecraft.class_2680;
import net.minecraft.class_2689;
import net.minecraft.class_2741;
import net.minecraft.class_2753;
import net.minecraft.class_3726;
import org.jetbrains.annotations.Nullable;

public class PedestalBlock extends DecorativeBlock {
    public static final class_2753 VERTICAL_DIRECTION = class_2741.field_28062;

    class_265 UP_SHAPE = class_259.method_17786(
            class_2248.method_9541(0, 0, 0, 16, 14, 16),
            class_2248.method_9541(1, 14, 1, 15, 15, 15),
            class_2248.method_9541(2, 15, 2, 14, 16, 14)
    );
    class_265 DOWN_SHAPE = class_259.method_17786(
            class_2248.method_9541(0, 2, 0, 16, 16, 16),
            class_2248.method_9541(1, 1, 1, 15, 2, 15),
            class_2248.method_9541(2, 0, 2, 14, 1, 14)
    );

    public PedestalBlock(class_2251 settings, class_2248 fullBlock) {
        super(settings, fullBlock);
        method_9590(method_9564().method_11657(VERTICAL_DIRECTION, class_2350.field_11036));
    }

    public static PedestalBlock ofBlock(class_2248 fullBlock) {
        return new PedestalBlock(class_2251.method_9630(fullBlock), fullBlock);
    }

    public static PedestalBlock ofWoodBlock(class_2248 woodBlock) {
        PedestalBlock pedestalBlock = ofBlock(woodBlock);
        pedestalBlock.isWood = true;
        return pedestalBlock;
    }

    @Override
    protected void method_9515(class_2689.class_2690<class_2248, class_2680> builder) {
        super.method_9515(builder);
        builder.method_11667(VERTICAL_DIRECTION);
    }

    @Nullable
    @Override
    public class_2680 method_9605(class_1750 ctx) {
        return method_9564().method_11657(VERTICAL_DIRECTION, ctx.method_32760().method_10153());
    }

    @Override
    public class_265 method_9530(class_2680 state, class_1922 view, class_2338 pos, class_3726 context) {
        return state.method_11654(VERTICAL_DIRECTION) == class_2350.field_11036 ? UP_SHAPE : DOWN_SHAPE;
    }
}
